# -*-coding:utf-8-*-
# from random_ua import RandomUA
#
# d = RandomUA()
# for i in range(100000):
#     print(d.random_android())
from random_ua import RandomUA
d = RandomUA()
print(d.random_android())
